==> node-typescript_4.8.4%2Bds1.orig.tar.xz: TypeScript-4.8.4/tests/baselines/reference/tscWatch/forceConsistentCasingInFileNames/when-Windows-style-drive-root-is-lowercase.js <==
Input::
//// [c:/project/a.ts]

export const a = 1;
export const b = 2;


//// [c:/project/b.ts]

import { a } from "C://project/a"
import { b } from "c://project/a"

a;b;


//// [c:/a/lib/lib.d.ts]
/// <reference no-default-lib="true"/>
interface Boolean {}
interface Function {}
interface CallableFunction {}
interface NewableFunction {}
interface IArguments {}
interface Number { toExponential: any; }
interface Object {}
interface RegExp {}
interface String { charAt: any; }
interface Array<T> { length: number; [n: number]: T; }

//// [c:/project/tsconfig.json]
{"compilerOptions":{"forceConsistentCasingInFileNames":true}}


c:/a/lib/tsc.js --w --p c://project --explainFiles
Output::
>> Screen clear
[[90m12:00:17 AM[0m] Starting compilation in watch mode...

a/lib/lib.d.ts
  Default library for target 'es3'
project/a.ts
  Matched by default include pattern '**/*'
  Imported via "C://project/a" from file 'project/b.ts'
  Imported via "c://project/a" from file 'project/b.ts'
project/b.ts
  Matched by default include pattern '**/*'
[[90m12:00:22 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["c:/project/a.ts","c:/project/b.ts"]
Program options: {"forceConsistentCasingInFileNames":true,"watch":true,"project":"c:/project","explainFiles":true,"configFilePath":"c:/project/tsconfig.json"}
Program structureReused: Not
Program files::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Semantic diagnostics in builder refreshed for::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Shape signatures in builder refreshed for::
c:/a/lib/lib.d.ts (used version)
c:/project/a.ts (used version)
c:/project/b.ts (used version)

WatchedFiles::
c:/project/tsconfig.json:
  {"fileName":"c:/project/tsconfig.json","pollingInterval":250}
c:/project/a.ts:
  {"fileName":"c:/project/a.ts","pollingInterval":250}
c:/project/b.ts:
  {"fileName":"c:/project/b.ts","pollingInterval":250}
c:/a/lib/lib.d.ts:
  {"fileName":"c:/a/lib/lib.d.ts","pollingInterval":250}
c:/project/node_modules/@types:
  {"fileName":"c:/project/node_modules/@types","pollingInterval":500}

FsWatches::

FsWatchesRecursive::
c:/project:
  {"directoryName":"c:/project"}

exitCode:: ExitStatus.undefined

//// [c:/project/a.js]
"use strict";
exports.__esModule = true;
exports.b = exports.a = void 0;
exports.a = 1;
exports.b = 2;


//// [c:/project/b.js]
"use strict";
exports.__esModule = true;
var a_1 = require("C://project/a");
var a_2 = require("c://project/a");
a_1.a;
a_2.b;



Change:: Prepend a line to moduleA

Input::
//// [c:/project/a.ts]
// some comment
                        
export const a = 1;
export const b = 2;



Output::
>> Screen clear
[[90m12:00:25 AM[0m] File change detected. Starting incremental compilation...

a/lib/lib.d.ts
  Default library for target 'es3'
project/a.ts
  Matched by default include pattern '**/*'
  Imported via "C://project/a" from file 'project/b.ts'
  Imported via "c://project/a" from file 'project/b.ts'
project/b.ts
  Matched by default include pattern '**/*'
[[90m12:00:32 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["c:/project/a.ts","c:/project/b.ts"]
Program options: {"forceConsistentCasingInFileNames":true,"watch":true,"project":"c:/project","explainFiles":true,"configFilePath":"c:/project/tsconfig.json"}
Program structureReused: Completely
Program files::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Semantic diagnostics in builder refreshed for::
c:/project/a.ts
c:/project/b.ts

Shape signatures in builder refreshed for::
c:/project/a.ts (computed .d.ts)
c:/project/b.ts (computed .d.ts)

WatchedFiles::
c:/project/tsconfig.json:
  {"fileName":"c:/project/tsconfig.json","pollingInterval":250}
c:/project/a.ts:
  {"fileName":"c:/project/a.ts","pollingInterval":250}
c:/project/b.ts:
  {"fileName":"c:/project/b.ts","pollingInterval":250}
c:/a/lib/lib.d.ts:
  {"fileName":"c:/a/lib/lib.d.ts","pollingInterval":250}
c:/project/node_modules/@types:
  {"fileName":"c:/project/node_modules/@types","pollingInterval":500}

FsWatches::

FsWatchesRecursive::
c:/project:
  {"directoryName":"c:/project"}

exitCode:: ExitStatus.undefined

//// [c:/project/a.js]
"use strict";
// some comment
exports.__esModule = true;
exports.b = exports.a = void 0;
exports.a = 1;
exports.b = 2;


//// [c:/project/b.js] file written with same contents

==> node-typescript_5.1.6%2Bds1.orig.tar.xz: TypeScript-5.1.6/tests/baselines/reference/tscWatch/forceConsistentCasingInFileNames/when-Windows-style-drive-root-is-lowercase.js <==
currentDirectory:: c:/ useCaseSensitiveFileNames: false
Input::
//// [c:/project/a.ts]

export const a = 1;
export const b = 2;


//// [c:/project/b.ts]

import { a } from "C://project/a"
import { b } from "c://project/a"

a;b;


//// [c:/a/lib/lib.d.ts]
/// <reference no-default-lib="true"/>
interface Boolean {}
interface Function {}
interface CallableFunction {}
interface NewableFunction {}
interface IArguments {}
interface Number { toExponential: any; }
interface Object {}
interface RegExp {}
interface String { charAt: any; }
interface Array<T> { length: number; [n: number]: T; }

//// [c:/project/tsconfig.json]
{"compilerOptions":{"forceConsistentCasingInFileNames":true}}


c:/a/lib/tsc.js --w --p c://project --explainFiles
Output::
>> Screen clear
[[90m12:00:17 AM[0m] Starting compilation in watch mode...

a/lib/lib.d.ts
  Default library for target 'es5'
project/a.ts
  Matched by default include pattern '**/*'
  Imported via "C://project/a" from file 'project/b.ts'
  Imported via "c://project/a" from file 'project/b.ts'
project/b.ts
  Matched by default include pattern '**/*'
[[90m12:00:22 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["c:/project/a.ts","c:/project/b.ts"]
Program options: {"forceConsistentCasingInFileNames":true,"watch":true,"project":"c:/project","explainFiles":true,"configFilePath":"c:/project/tsconfig.json"}
Program structureReused: Not
Program files::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Semantic diagnostics in builder refreshed for::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Shape signatures in builder refreshed for::
c:/a/lib/lib.d.ts (used version)
c:/project/a.ts (used version)
c:/project/b.ts (used version)

PolledWatches::
c:/project/node_modules/@types: *new*
  {"pollingInterval":500}

FsWatches::
c:/project/tsconfig.json: *new*
  {}
c:/project/a.ts: *new*
  {}
c:/project/b.ts: *new*
  {}
c:/a/lib/lib.d.ts: *new*
  {}

FsWatchesRecursive::
c:/project: *new*
  {}

exitCode:: ExitStatus.undefined

//// [c:/project/a.js]
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.b = exports.a = void 0;
exports.a = 1;
exports.b = 2;


//// [c:/project/b.js]
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var a_1 = require("C://project/a");
var a_2 = require("c://project/a");
a_1.a;
a_2.b;



Change:: Prepend a line to moduleA

Input::
//// [c:/project/a.ts]
// some comment
                        
export const a = 1;
export const b = 2;



Before running Timeout callback:: count: 1
1: timerToUpdateProgram
After running Timeout callback:: count: 0
Output::
>> Screen clear
[[90m12:00:25 AM[0m] File change detected. Starting incremental compilation...

a/lib/lib.d.ts
  Default library for target 'es5'
project/a.ts
  Matched by default include pattern '**/*'
  Imported via "C://project/a" from file 'project/b.ts'
  Imported via "c://project/a" from file 'project/b.ts'
project/b.ts
  Matched by default include pattern '**/*'
[[90m12:00:32 AM[0m] Found 0 errors. Watching for file changes.



Program root files: ["c:/project/a.ts","c:/project/b.ts"]
Program options: {"forceConsistentCasingInFileNames":true,"watch":true,"project":"c:/project","explainFiles":true,"configFilePath":"c:/project/tsconfig.json"}
Program structureReused: Completely
Program files::
c:/a/lib/lib.d.ts
c:/project/a.ts
c:/project/b.ts

Semantic diagnostics in builder refreshed for::
c:/project/a.ts
c:/project/b.ts

Shape signatures in builder refreshed for::
c:/project/a.ts (computed .d.ts)
c:/project/b.ts (computed .d.ts)

exitCode:: ExitStatus.undefined

//// [c:/project/a.js]
"use strict";
// some comment
Object.defineProperty(exports, "__esModule", { value: true });
exports.b = exports.a = void 0;
exports.a = 1;
exports.b = 2;


//// [c:/project/b.js] file written with same contents
